@@ -531,6 +531,36 @@ static char *xpm_r_bracket[] = {
 "                        ",
 "                        "
 };
+static char *xpm_r2_bracket[] = {
+"24 24 3 1",
+"  c None",
+". c #0000A0",
+"# c #505000",
+"                        ",
+"                        ",
+"     ##        ##       ",
+"    #     ..     #      ",
+"    #    .  .    #      ",
+"   #    .    .    #     ",
+"   #   .      .   #     ",
+"  #   .        .   #    ",
+"  #  .          .  #    ",
+"  #  .          .  #    ",
+"  #  .          .  #    ",
+"  #  .          .  #    ",
+"  #  .          .  #    ",
+"  #  .          .  #    ",
+"  #   .        .   #    ",
+"   #   .      .   #     ",
+"   #    .    .    #     ",
+"    #    .  .    #      ",
+"    #     ..     #      ",
+"     #          #       ",
+"      ##      ##        ",
+"                        ",
+"                        ",
+"                        "
+};
 static char *xpm_brace[] = {
 "24 24 3 1",
 "  c None",
