@@ -17,7 +17,6 @@
 #  endif
 #endif
 
-#define VERSION "1.6.10"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -113,7 +112,7 @@ char *orientation[2]={"-p 1","-l 1"};
 int orient;
 float printscale;
 int printcmd;
-char *printcommand[2]={"lpr -P","lp -d"};
+char *printcommand[4]={"lpr -P","lp -d","kprinter -d","gtklp -d"};
 char *queuename;
 char datadir[PATH_MAX];
 char datamask[PATH_MAX];
@@ -223,7 +222,7 @@ extern int export_svg(char *filename);
 extern int export_latex_pic(char *filename, float scalefactor);
 extern int export_ps_pic(char *filename, float scalefactor);
 extern int export_png_pic(char *filename, float scalefactor);
-extern int print_ps_pic(char *filename);
+extern int print_ps_pic(void);
 extern int export_fw(char *filename);
 extern int export_mdl_mol(FILE *fp, int topipe);
 extern int export_emf(char *filename);
