@@ -17,7 +17,6 @@
 #  endif
 #endif
 
-#define VERSION "1.6.10"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -109,7 +108,7 @@ extern char *orientation[2];
 extern int orient;
 extern float printscale;
 extern int printcmd;
-extern char *printcommand[2];
+extern char *printcommand[4];
 extern char *queuename;
 extern char datadir[PATH_MAX];
 extern char datamask[PATH_MAX];
@@ -231,7 +230,7 @@ extern int import_mdl_mol(char *filename,int skip);
 extern int import_pdb(char *filename);
 extern int export_latex_pic(char *filename,float scalefactor);
 extern int export_ps_pic(char *filename, float scalefactor);
-extern int print_ps_pic(char *filename);
+extern int print_ps_pic(void);
 extern void xfig_line (FILE*, int, int, int, int); 
 extern void xfig_wedge (FILE*, int, int, int, int, int, int); 
 extern void xfig_wiggly (FILE*, int, int, int, int);
