@@ -157,18 +157,19 @@ Display_Mol ()
     int tx=hpc->tx;
     int ty=hpc->ty;
 #if 1
+//constant clipping factor works better than original 4*size_factor
 	if ( !use_whiteout) {
 		i=has_label(hpc->x,hpc->y);
 		if (i>=0) {
 		int ox=x;
-				x += (4.*size_factor*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
-				y += (4.*size_factor*(i+1)/calc_vector(abs(tx-ox),abs(ty-y))) *(ty-y);
+				x += (3.2*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				y += (3.2*(i+1)/calc_vector(abs(tx-ox),abs(ty-y))) *(ty-y);
 				}
 		i=has_label(hpc->tx,hpc->ty);
 		if (i>=0) {
 		int otx=tx;
-				tx -= (4.*size_factor*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
-				ty -= (4.*size_factor*(i+1)/calc_vector(abs(otx-x),abs(ty-y))) *(ty-y);
+				tx -= (3.2*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				ty -= (3.2*(i+1)/calc_vector(abs(otx-x),abs(ty-y))) *(ty-y);
 				}
 		}		
 #endif
@@ -182,7 +183,7 @@ Display_Mol ()
 	    coord = multi_bonds (x, y, tx, ty, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
-	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
+	    Drawline (x, y, tx, ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	  }
 	  break;
@@ -248,11 +249,11 @@ Display_Mol ()
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (x, y, tx, ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
-	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, mb_dist);
+	    coord = multi_bonds (tx, ty, x, y, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (x, y, tx, ty,
-		      hpc->smarked + hpc->tmarked,hpc->color);
+	      hpc->smarked + hpc->tmarked,hpc->color);
 	  }
 	  break;
 	case 14:
@@ -1162,6 +1163,10 @@ memset(l,0,8*sizeof(gchar));
 	{
 	  symbol[d] = TRUE;
 	  text[d] = hl;
+	if (text[d] == '+') 
+	  text[d]=8005;//QUAK
+	else if (text[d] == '-') 
+	  text[d]=8006;//QUAK
           c = g_utf8_next_char(c);
 	  --n;
 	}
@@ -1467,6 +1472,7 @@ memset(l,0,8*sizeof(gchar));
 /* erase a circular area slightly larger than the current character to
    create some space around the label */
    if (text[d] != 183) {
+if (use_whiteout) fprintf(stderr,"whitespace\n");
     if (preview)
       gdk_draw_arc (picture, drawing_area->style->white_gc, 1,
 		    x - 5 * size_factor,
