@@ -38,12 +38,12 @@
 
 #include "config.h"
 
-#ifdef DISABLE_NLS
-#define _(Text) Text
-#else
-#include <libintl.h>
-#define _(Text) gettext(Text)
-#endif
+//#ifdef DISABLE_NLS
+//#define _(Text) Text
+//#else
+//#include <libintl.h>
+//#define _(Text) gettext(Text)
+//#endif
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkbutton.h>
